@@ -16,19 +16,16 @@ test_that("plotSelfInteractionRatios behaves as expected", {
         "Unknown")
 
     pp <- plotSelfInteractionRatios(exampleHiCDOCDataSetProcessed, 1)
-    expect_is(pp, "ggplot")
-    expect_identical(
-        pp$labels,
-        list(
-            "caption" = "Quality control:\nA/B assignment reliability: OK",
-            "colour" = "Compartment",
-            "x" = "Compartment",
-            "y" = "Interaction difference",
-            "title" = paste0("Differences between self-interactions ",
-                             "and other interactions"),
-            "subtitle" = "Chromosome X"
-        )
-    )
+    expect_true(ggplot2::is_ggplot(pp))
+    labs <- ggplot2::get_labs(pp)
+    expect_equivalent(labs[["caption"]], 
+        "Quality control:\nA/B assignment reliability: OK")
+    expect_equivalent(labs[["x"]], "Compartment")
+    expect_equivalent(labs[["y"]], "Interaction difference")
+    expect_equivalent(labs[["title"]], 
+        "Differences between self-interactions and other interactions")
+    expect_equivalent(labs[["colour"]], "Compartment")
+    expect_equivalent(labs[["subtitle"]], "Chromosome X")
     expect_is(pp$layers[[1]]$geom, "GeomPoint")
     expect_is(pp$layers[[2]]$geom, "GeomBoxplot")
     # No error when printed
